==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/plugins/genecut/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>GenecutOPWidget</name>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Login form</source>
        <translation>Форма авторизации</translation>
    </message>
    <message>
        <source>username@server.com</source>
        <translation></translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Показать пароль</translation>
    </message>
    <message>
        <source>Remember me</source>
        <translation>Запомнить меня</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Авторизироваться</translation>
    </message>
    <message>
        <source>Forgot password</source>
        <translation>Забыли пароль</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Зарегистрироваться</translation>
    </message>
    <message>
        <source>Reset your password</source>
        <translation>Восстановить пароль</translation>
    </message>
    <message>
        <source>Send password reset email</source>
        <translation>Отправить на почту</translation>
    </message>
    <message>
        <source>Back to login</source>
        <translation>Обратно к авторизации</translation>
    </message>
    <message>
        <source>Welcome, </source>
        <translation>Добро пожаловать, </translation>
    </message>
    <message>
        <source>Open this sequence in GeneCut</source>
        <translation>Открыть последовательность в GeneCut</translation>
    </message>
    <message>
        <source>Fetch results</source>
        <translation>Вытянуть результаты</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Short description:</source>
        <translation>Краткое описание:</translation>
    </message>
    <message>
        <source>Remove selected report</source>
        <translation>Удалить выделенный отчет</translation>
    </message>
    <message>
        <source>Get the input sequence</source>
        <translation>Скачать входную последовательнсть</translation>
    </message>
    <message>
        <source>Open full report in GeneCut</source>
        <translation>Открыть полный отчет в GeneCut</translation>
    </message>
    <message>
        <source>Get the result sequence</source>
        <translation>Скачать результирующую последовательность</translation>
    </message>
    <message>
        <source>Compare input and result sequences</source>
        <translation>Сравнить</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <source>Register form</source>
        <translation>Форма регистрации</translation>
    </message>
    <message>
        <source>Password confirmation</source>
        <translation>Подтверждение пароля</translation>
    </message>
    <message>
        <source>First name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Last name</source>
        <translation>Фамилия</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;meta charset=&quot;utf-8&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
hr { height: 1px; border-width: 0; }
li.unchecked::marker { content: &quot;\2610&quot;; }
li.checked::marker { content: &quot;\2612&quot;; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Segoe UI&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;meta charset=&quot;utf-8&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
hr { height: 1px; border-width: 0; }
li.unchecked::marker { content: &quot;\2610&quot;; }
li.checked::marker { content: &quot;\2612&quot;; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Segoe UI&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Subscribe to newsletters</source>
        <translation>Подписаться на новостную рассылку</translation>
    </message>
</context>
<context>
    <name>U2::GenecutHttpFileAdapter</name>
    <message>
        <source>Getting data from %1</source>
        <translation>Скачиваем данные из %1</translation>
    </message>
</context>
<context>
    <name>U2::GenecutHttpFileAdapterFactory</name>
    <message>
        <source>Genecut HTTP</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::GenecutOPWidget</name>
    <message>
        <source>calculation wasn&apos;t finished correctly, the result sequence and the comparison with the input sequence are not available</source>
        <translation>расчет был завершен не корректно, результирующая последовательность и сравнение недоступны</translation>
    </message>
    <message>
        <source>the input sequence is amino, can&apos;t compare with the nucleic result</source>
        <translation>входная последовательность аминокислотная, невозможно сравнить с выходной нуклеотидной</translation>
    </message>
    <message>
        <source>Welcome, %1</source>
        <translation>Добро пожаловать, %1</translation>
    </message>
    <message>
        <source>check your email</source>
        <translation>проверьте вашу почту</translation>
    </message>
    <message>
        <source>results have been fetched</source>
        <translation>Результаты были скачаны</translation>
    </message>
    <message>
        <source>user created! Check your email</source>
        <translation>пользователь создан! Проверьте вашу почту</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Ошибка: </translation>
    </message>
    <message>
        <source>Success: </source>
        <translation>Успех: </translation>
    </message>
    <message>
        <source>Warning: </source>
        <translation>Предупреждение: </translation>
    </message>
    <message>
        <source>passwords do not match</source>
        <translation>пароли не совпадают</translation>
    </message>
    <message>
        <source>input</source>
        <translation>входная</translation>
    </message>
    <message>
        <source>result</source>
        <translation>результирующая</translation>
    </message>
    <message>
        <source>Can&apos;t save the %1 file, probably, no permissions to write to the data directory: %2</source>
        <translation>Не могу сохранить %1, вероятно, нет прав на запись в директорию: %2</translation>
    </message>
    <message>
        <source>the %1 file has been saved</source>
        <translation>файл %1 сохранен</translation>
    </message>
    <message>
        <source>The %1 file has been saved to %2</source>
        <translation>Файл %1 сохранен в %2</translation>
    </message>
    <message>
        <source>Can&apos;t load the %1 file %2</source>
        <translation>Невозможно загрузить %1 в %2</translation>
    </message>
    <message>
        <source>Can&apos;t merge input and result into alignment</source>
        <translation>Невозможно слить входную и результирующую последовательности в выравнивание</translation>
    </message>
    <message>
        <source>GeneCut test server is in use</source>
        <translation>Используется тестовый сервер GeneCut</translation>
    </message>
    <message>
        <source>password should be between 6 and 31 symbols length</source>
        <translation>пароль должен быть от 6 до 31 символа длиной</translation>
    </message>
</context>
<context>
    <name>U2::GenecutOPWidgetFactory</name>
    <message>
        <source>Genecut desktop</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::GenecutPlugin</name>
    <message>
        <source>Desktop acess to GeneCut calculation results</source>
        <translation>Доступ из рабочего стола к расчетам, произведенным в GeneCut</translation>
    </message>
</context>
</TS>

==> ugene_52.1+dfsg.orig.tar.xz: ugene-52.1/src/plugins/genecut/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>GenecutOPWidget</name>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Login form</source>
        <translation>Форма авторизации</translation>
    </message>
    <message>
        <source>username@server.com</source>
        <translation></translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Показать пароль</translation>
    </message>
    <message>
        <source>Remember me</source>
        <translation>Запомнить меня</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Авторизироваться</translation>
    </message>
    <message>
        <source>Forgot password</source>
        <translation>Забыли пароль</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Зарегистрироваться</translation>
    </message>
    <message>
        <source>Reset your password</source>
        <translation>Восстановить пароль</translation>
    </message>
    <message>
        <source>Send password reset email</source>
        <translation>Отправить на почту</translation>
    </message>
    <message>
        <source>Back to login</source>
        <translation>Обратно к авторизации</translation>
    </message>
    <message>
        <source>Welcome, </source>
        <translation>Добро пожаловать, </translation>
    </message>
    <message>
        <source>Open this sequence in GeneCut</source>
        <translation>Открыть последовательность в GeneCut</translation>
    </message>
    <message>
        <source>Fetch results</source>
        <translation>Вытянуть результаты</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Short description:</source>
        <translation>Краткое описание:</translation>
    </message>
    <message>
        <source>Remove selected report</source>
        <translation>Удалить выделенный отчет</translation>
    </message>
    <message>
        <source>Get the input sequence</source>
        <translation>Скачать входную последовательнсть</translation>
    </message>
    <message>
        <source>Open full report in GeneCut</source>
        <translation>Открыть полный отчет в GeneCut</translation>
    </message>
    <message>
        <source>Get the result sequence</source>
        <translation>Скачать результирующую последовательность</translation>
    </message>
    <message>
        <source>Compare input and result sequences</source>
        <translation>Сравнить</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <source>Register form</source>
        <translation>Форма регистрации</translation>
    </message>
    <message>
        <source>Password confirmation</source>
        <translation>Подтверждение пароля</translation>
    </message>
    <message>
        <source>First name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Last name</source>
        <translation>Фамилия</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;meta charset=&quot;utf-8&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
hr { height: 1px; border-width: 0; }
li.unchecked::marker { content: &quot;\2610&quot;; }
li.checked::marker { content: &quot;\2612&quot;; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Segoe UI&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;meta charset=&quot;utf-8&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
hr { height: 1px; border-width: 0; }
li.unchecked::marker { content: &quot;\2610&quot;; }
li.checked::marker { content: &quot;\2612&quot;; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Segoe UI&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Subscribe to newsletters</source>
        <translation>Подписаться на новостную рассылку</translation>
    </message>
</context>
<context>
    <name>U2::GenecutHttpFileAdapter</name>
    <message>
        <source>Getting data from %1</source>
        <translation>Скачиваем данные из %1</translation>
    </message>
</context>
<context>
    <name>U2::GenecutHttpFileAdapterFactory</name>
    <message>
        <source>Genecut HTTP</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::GenecutOPWidget</name>
    <message>
        <source>calculation wasn&apos;t finished correctly, the result sequence and the comparison with the input sequence are not available</source>
        <translation>расчет был завершен не корректно, результирующая последовательность и сравнение недоступны</translation>
    </message>
    <message>
        <source>the input sequence is amino, can&apos;t compare with the nucleic result</source>
        <translation>входная последовательность аминокислотная, невозможно сравнить с выходной нуклеотидной</translation>
    </message>
    <message>
        <source>Welcome, %1</source>
        <translation>Добро пожаловать, %1</translation>
    </message>
    <message>
        <source>check your email</source>
        <translation>проверьте вашу почту</translation>
    </message>
    <message>
        <source>results have been fetched</source>
        <translation>Результаты были скачаны</translation>
    </message>
    <message>
        <source>user created! Check your email</source>
        <translation>пользователь создан! Проверьте вашу почту</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Ошибка: </translation>
    </message>
    <message>
        <source>Success: </source>
        <translation>Успех: </translation>
    </message>
    <message>
        <source>Warning: </source>
        <translation>Предупреждение: </translation>
    </message>
    <message>
        <source>passwords do not match</source>
        <translation>пароли не совпадают</translation>
    </message>
    <message>
        <source>input</source>
        <translation>входная</translation>
    </message>
    <message>
        <source>result</source>
        <translation>результирующая</translation>
    </message>
    <message>
        <source>Can&apos;t save the %1 file, probably, no permissions to write to the data directory: %2</source>
        <translation>Не могу сохранить %1, вероятно, нет прав на запись в директорию: %2</translation>
    </message>
    <message>
        <source>the %1 file has been saved</source>
        <translation>файл %1 сохранен</translation>
    </message>
    <message>
        <source>The %1 file has been saved to %2</source>
        <translation>Файл %1 сохранен в %2</translation>
    </message>
    <message>
        <source>Can&apos;t load the %1 file %2</source>
        <translation>Невозможно загрузить %1 в %2</translation>
    </message>
    <message>
        <source>Can&apos;t merge input and result into alignment</source>
        <translation>Невозможно слить входную и результирующую последовательности в выравнивание</translation>
    </message>
    <message>
        <source>GeneCut test server is in use</source>
        <translation>Используется тестовый сервер GeneCut</translation>
    </message>
    <message>
        <source>password should be between 6 and 31 symbols length</source>
        <translation>пароль должен быть от 6 до 31 символа длиной</translation>
    </message>
</context>
<context>
    <name>U2::GenecutOPWidgetFactory</name>
    <message>
        <source>Genecut desktop</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::GenecutPlugin</name>
    <message>
        <source>Desktop access to GeneCut calculation results</source>
        <translation>Доступ из рабочего стола к расчетам, произведенным в GeneCut</translation>
    </message>
</context>
</TS>
